
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: floor, HOME, MILLISECONDS_ABBR, NETWORK_LABEL, Settings, WORLD

local format = format
local GetNetStats = GetNetStats

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(SixUI) -- AddOn, Border, Constants, Database
local M = A:NewModule("Display Latency")
local O = LibStub("LibDataBroker-1.1"):NewDataObject("SixUI Latency", {
	type = "data source",
	text = format("%s %s", 0, MILLISECONDS_ABBR),
	value = "0",
	suffix = MILLISECONDS_ABBR,
	label = "Latency",
})
local Tooltip = LibStub("SixTooltip-1.0"):CreateTooltip({
	anchor = UIParent,
	columnJustification = {"LEFT", "LEFT"},
	font = C.TEXT_REGULAR,
	headerFont = C.TEXT_LARGE,
	key = "SixUI Latency",
	numColumns = 2,
	separatorHeight = C.TOOLTIP_SEPARATOR_HEIGHT,
})

local bandwidthIn = 0
local bandwidthOut = 0
local latencyHome = 0
local latencyWorld = 0

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:ScheduleRepeatingTimer("Update", 1)
end

function M:Update()
	bandwidthIn, bandwidthOut, latencyHome, latencyWorld = GetNetStats()

	O.text = format("%s %s", latencyWorld, O.suffix)
	O.value = latencyWorld

	Tooltip:Refresh()
end

-------------------------------------------------------------------------------
-- DataObject
-------------------------------------------------------------------------------

function O.OnClick(frame, button)
	if not M.NETWORK_CATEGORY_ID then
		M.NETWORK_CATEGORY_ID = A.GetSettingsCategoryID(NETWORK_LABEL)
	end

	Settings.OpenToCategory(M.NETWORK_CATEGORY_ID)
end

function O.OnEnter(frame)
	if frame then
		Tooltip:UpdateConfig({anchor = frame})
	end

	Tooltip:Show()
end

-------------------------------------------------------------------------------
-- Tooltip
-------------------------------------------------------------------------------

function Tooltip:OnShow()
	-- Latency
	self:AddHeader("Latency")
	self:AddSeparator(C.TOOLTIP_SEPARATOR_HEIGHT)
	self:AddLine(HOME, latencyHome .. " " .. MILLISECONDS_ABBR)
	self:AddLine(WORLD, latencyWorld .. " " .. MILLISECONDS_ABBR)
	self:AddSeparator(5, 0, 0, 0, 0)

	-- Bandwidth
	self:AddHeader("Bandwidth")
	self:AddSeparator(C.TOOLTIP_SEPARATOR_HEIGHT)
	self:AddLine("In", floor(bandwidthIn) .. " Kbps")
	self:AddLine("Out", floor(bandwidthOut) .. " Kbps")
end
